@@ -29,9 +29,6 @@ package MHonArc::CharEnt;
 use strict;
 use MHonArc::CharMaps;
 use MHonArc::Char;
-use MHonArc;
-
-our $VERSION = $MHonArc::VERSION;
 
 ##---------------------------------------------------------------------------
 ##      Charset specification to mapping
