@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	$Id: UTF8.pm,v 1.5 2002/12/20 08:01:11 ehood Exp $
+##	$Id: UTF8.pm,v 1.6 2003/03/05 22:17:15 ehood Exp $
 ##  Author:
 ##      Earl Hood       earl@earlhood.com
 ##  Description:
@@ -30,42 +30,38 @@ use strict;
 use MHonArc::CharMaps;
 
 BEGIN {
-    eval {
-	require MHonArc::UTF8::Encode;
-    };
+    eval { require MHonArc::UTF8::Encode; };
     if (!$@) {
-	# Encode module available
-	*entify    = \&_entify;
-	*clip      = \&MHonArc::UTF8::Encode::clip;
-	*to_utf8   = \&MHonArc::UTF8::Encode::to_utf8;
-	*str2sgml  = \&MHonArc::UTF8::Encode::str2sgml;
+        # Encode module available
+        *entify   = \&_entify;
+        *clip     = \&MHonArc::UTF8::Encode::clip;
+        *to_utf8  = \&MHonArc::UTF8::Encode::to_utf8;
+        *str2sgml = \&MHonArc::UTF8::Encode::str2sgml;
     } else {
-	eval {
-	    require MHonArc::UTF8::MapUTF8;
-	};
-	if (!$@) {
-	    # Unicode::MapUTF8 module available
-	    *entify    = \&_entify;
-	    *clip      = \&MHonArc::UTF8::MapUTF8::clip;
-	    *to_utf8   = \&MHonArc::UTF8::MapUTF8::to_utf8;
-	    *str2sgml  = \&MHonArc::UTF8::MapUTF8::str2sgml;
-	} else {
-	    # Fallback to homegrown implementation
-	    require MHonArc::UTF8::MhaEncode;
-	    *entify    = \&_entify;
-	    *clip      = \&MHonArc::UTF8::MhaEncode::clip;
-	    *to_utf8   = \&MHonArc::UTF8::MhaEncode::to_utf8;
-	    *str2sgml  = \&MHonArc::UTF8::MhaEncode::str2sgml;
-	}
+        eval { require MHonArc::UTF8::MapUTF8; };
+        if (!$@) {
+            # Unicode::MapUTF8 module available
+            *entify   = \&_entify;
+            *clip     = \&MHonArc::UTF8::MapUTF8::clip;
+            *to_utf8  = \&MHonArc::UTF8::MapUTF8::to_utf8;
+            *str2sgml = \&MHonArc::UTF8::MapUTF8::str2sgml;
+        } else {
+            # Fallback to homegrown implementation
+            require MHonArc::UTF8::MhaEncode;
+            *entify   = \&_entify;
+            *clip     = \&MHonArc::UTF8::MhaEncode::clip;
+            *to_utf8  = \&MHonArc::UTF8::MhaEncode::to_utf8;
+            *str2sgml = \&MHonArc::UTF8::MhaEncode::str2sgml;
+        }
     }
 }
 
 ##---------------------------------------------------------------------------##
 
 sub _entify {
-    my $text	= shift;
-    my $text_r  = ref($text) ? $text : \$text;
-    $$text_r =~ s/([\x22\x26\x3C\x3E\x40])/$HTMLSpecials{$1}/g;
+    my $text = shift;
+    my $text_r = ref($text) ? $text : \$text;
+    $$text_r =~ s/([$HTMLSpecials])/$HTMLSpecials{$1}/go;
     $$text_r;
 }
 
@@ -179,7 +175,7 @@ resources in the MHonArc documentation.
 
 =head1 VERSION
 
-C<$Id: UTF8.pm,v 1.5 2002/12/20 08:01:11 ehood Exp $>
+C<$Id: UTF8.pm,v 1.6 2003/03/05 22:17:15 ehood Exp $>
 
 =head1 AUTHOR
 
