@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	$Id: mhdysub.pl,v 2.10 2003/01/10 03:35:40 ehood Exp $
+##	$Id: mhdysub.pl,v 2.12 2009/05/03 20:11:27 ehood Exp $
 ##  Author:
 ##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
@@ -39,13 +39,13 @@ my $_sub_eval_cnt = 0;
 ##	      pre-dates Perl 5 where references were not supported.
 ##
 sub create_routines {
-    my($sub) = '';
+    my ($sub) = '';
 
     ##-----------------------------------------------------------------------
     ## exclude_field: Used to determine if field should be excluded from
     ## message header
     ##
-    $sub  =<<'EndOfRoutine';
+    $sub = <<'EndOfRoutine';
     sub exclude_field {
 	my($f) = shift;
 	my $ret = 0;
@@ -56,20 +56,19 @@ EndOfRoutine
     # expressions (a large || statement could also work).
     my $pat;
     foreach $pat (keys %HFieldsExc) {
-	$sub .= join('',
-		     'if ($f =~ /^',
-		     $pat,
-		     '/i) { $ret = 1;  last EXC_FIELD_SW; }',
-		     "\n");
+        $sub .= join('',
+            'if ($f =~ /^', $pat, '/i) { $ret = 1;  last EXC_FIELD_SW; }',
+            "\n");
     }
 
-    $sub .=<<'EndOfRoutine';
+    $sub .= <<'EndOfRoutine';
 	};
 	$ret;
     }
 EndOfRoutine
 
-    $sub .= "# $_sub_eval_cnt\n";  ++$_sub_eval_cnt;
+    $sub .= "# $_sub_eval_cnt\n";
+    ++$_sub_eval_cnt;
     eval $sub;
     die("ERROR: Unable to create exclude_field routine:\n$@\n") if $@;
 
@@ -77,7 +76,7 @@ EndOfRoutine
     ## subject_strip: Used to apply user-defined s/// operations on
     ## message subjects as they are read;
     ##
-    $sub  =<<EndOfRoutine;
+    $sub = <<EndOfRoutine;
     sub subject_strip {
 	local(\$_) = shift;
 	$SubStripCode;
@@ -85,17 +84,27 @@ EndOfRoutine
     }
 EndOfRoutine
 
-    $sub .= "# $_sub_eval_cnt\n";  ++$_sub_eval_cnt;
+    $sub .= "# $_sub_eval_cnt\n";
+    ++$_sub_eval_cnt;
     eval $sub;
     die("ERROR: Unable to create subject_strip routine:\n$@\n") if $@;
 
     ##-----------------------------------------------------------------------
     ##	Routine to determine last message number in use.
+    ##  If $LastMsgNum set, we return it after a sanity check
+    ##  is done.  If check fails, scan directory to determine last number.
     ##
-    $sub =<<'EndOfRoutine';
+    $sub = <<'EndOfRoutine';
     sub get_last_msg_num {
 	opendir(DIR, $OUTDIR) || die("ERROR: Unable to open $OUTDIR\n");
 	my($max) = -1;
+        if ($LastMsgNum >= 0) {
+           return $LastMsgNum if (
+                 -s $OUTDIR . $DIRSEP . msgnum_filename($LastMsgNum)) &&
+                 ((! -f $OUTDIR . $DIRSEP . msgnum_filename($LastMsgNum + 1))
+           );
+        }
+
 	my $msgrex = '^'.
 		     "\Q$MsgPrefix".
 		     '(\d+)\.'.
@@ -106,19 +115,21 @@ EndOfRoutine
 	foreach (readdir(DIR)) {
 	    if (/$msgrex/io) { $max = int($1)  if $1 > $max; }
 	}
-	close(DIR);
+	closedir(DIR);
+        $LastMsgNum = $max;
 	$max;
     }
 EndOfRoutine
 
-    $sub .= "# $_sub_eval_cnt\n";  ++$_sub_eval_cnt;
+    $sub .= "# $_sub_eval_cnt\n";
+    ++$_sub_eval_cnt;
     eval $sub;
     die("ERROR: Unable to create get_last_msg_num routine:\n$@\n") if $@;
 
     ##-----------------------------------------------------------------------
     ##	Routine to get base subject text from index
     ##
-    $sub =<<'EndOfRoutine';
+    $sub = <<'EndOfRoutine';
     sub get_base_subject {
 	my($ret) = ($Subject{$_[0]});
 	1 while $ret =~ s/$SubReplyRxp//io;
@@ -129,14 +140,15 @@ EndOfRoutine
     }
 EndOfRoutine
 
-    $sub .= "# $_sub_eval_cnt\n";  ++$_sub_eval_cnt;
+    $sub .= "# $_sub_eval_cnt\n";
+    ++$_sub_eval_cnt;
     eval $sub;
     die("ERROR: Unable to create get_base_subject routine:\n$@\n") if $@;
 
     ##-----------------------------------------------------------------------
     ##	Routine to rewrite mail addresses in message header
     ##
-    $sub =<<EndOfRoutine;
+    $sub = <<EndOfRoutine;
     sub rewrite_address {
 	package mhonarc::Pkg_rewrite_address;
 	local \$_ = mhonarc::dehtmlize(shift);
@@ -145,14 +157,15 @@ EndOfRoutine
     }
 EndOfRoutine
 
-    $sub .= "# $_sub_eval_cnt\n";  ++$_sub_eval_cnt;
+    $sub .= "# $_sub_eval_cnt\n";
+    ++$_sub_eval_cnt;
     eval $sub;
     die("ERROR: Unable to create rewrite_address routine:\n$@\n") if $@;
 
     ##-----------------------------------------------------------------------
     ##	Routine to rewrite raw mail addresses
     ##
-    $sub =<<EndOfRoutine;
+    $sub = <<EndOfRoutine;
 sub rewrite_raw_address {
     package mhonarc::Pkg_rewrite_raw_address;
     local \$_ = shift;
@@ -160,16 +173,17 @@ sub rewrite_raw_address {
     \$_;
 }
 EndOfRoutine
-    $sub .= "# $_sub_eval_cnt\n";  ++$_sub_eval_cnt;
+    $sub .= "# $_sub_eval_cnt\n";
+    ++$_sub_eval_cnt;
     eval $sub;
     die("ERROR: Unable to create rewrite_raw_address routine:\n$@\n")
-	if $@;
+        if $@;
 
     ##-----------------------------------------------------------------------
     ## message_exclude: User-defined code to check if a message should
     ## be added or not.
     ##
-    $sub  =<<EndOfRoutine;
+    $sub = <<EndOfRoutine;
     sub message_exclude {
 	package mhonarc::Pkg_message_exclude;
 	local(\$_) = shift;
@@ -177,7 +191,8 @@ EndOfRoutine
     }
 EndOfRoutine
 
-    $sub .= "# $_sub_eval_cnt\n";  ++$_sub_eval_cnt;
+    $sub .= "# $_sub_eval_cnt\n";
+    ++$_sub_eval_cnt;
     eval $sub;
     die("ERROR: Unable to create subject_strip routine:\n$@\n") if $@;
 
